@@ -585,6 +585,8 @@ class Database(object):
                                   "using replication.")
             self.close()
             self.backend = xapian.Database(self.db_path)
+            for parser in self.parsers_by_language.itervalues():
+                parser.set_database(self.backend)
 
         if refresh_if_needed and self.is_metadata_changed:
             self.meta_refresh()
