@@ -144,9 +144,9 @@ class Schema(schema.Form):
             if element.lower:
                 term = term.lower()
             if element.prefix:
-                memo.add_term(_prefix(name, term), element.boolean)
+                memo.add_term(_prefix(name, term), element.boolean, element.wdf_inc)
             else:
-                memo.add_term(term, element.boolean)
+                memo.add_term(term, element.boolean, element.wdf_inc)
             if element.sortable:
                 memo.add_value(name, value, type)
             return value
@@ -205,9 +205,9 @@ class Schema(schema.Form):
                     term = value.lower()
                 if element.string_prefix:
                     memo.add_term(_prefix(element.string_prefix, term),
-                                   element.boolean)
+                                   element.boolean, element.wdf_inc)
                 else:
-                    memo.add_term(term)
+                    memo.add_term(term, False, element.wdf_inc)
 
         if element.sortable:
             memo.add_value(name, value, 'string')
@@ -220,7 +220,9 @@ class Schema(schema.Form):
                       element.positions,
                       element.stem,
                       element.stop,
-                      element.spelling)
+                      element.spelling,
+                      element.wdf_inc,
+                      element.position_start)
         return value
 
     def _handle_numericrange(self, element):
@@ -241,16 +243,14 @@ class Schema(schema.Form):
         for i in xrange(minv, maxv, step):
             val = "%s_%s" % (i, i + step)
             val = val.lower()
-            self._memo.add_term(_prefix(element.name, val), True)
+            self._memo.add_term(_prefix(element.name, val), True, 
+                                element.wdf_inc)
         return True
 
     def _handle_location(self, element):
         memo = self._memo
         h = 'loc_' + element.hash(element.radians)
-        if element.boolean:
-            memo.add_term(h, boolean=True)
-        else:
-            memo.add_term(h)
+        memo.add_term(h, element.boolean, element.wdf_inc)
         if element.sortable:
             memo.add_value(element.name, h, 'location')
         return True
@@ -310,6 +310,11 @@ class _BaseElement(object):
     """Whether to lowercase the value when indexing the element's term.
     """
 
+    wdf_inc = 1
+    """How much to increment the within document frequency for terms
+    generated by this element.
+    """
+
     @classmethod
     def property(cls, fn):
         """Decorator for wrapping a schema class method getter with an
@@ -401,6 +406,13 @@ class Text(schema.String, _BaseElement):
     of a larger database.
     """
 
+    position_start = None
+    """Tells the indexer which position to start at when indexing text.
+
+    If None, position is automatically determined on a per-document
+    basis so that multiple text fields to *not* overlap.
+    """
+
     stem = True
     """If the language is set, stem the text.
     """
